
### Code for taking the median values across 99 samples generated during
### rarefaction process for Khaliq et al. 2024 Nature Communications

### Imran Khaliq #####
# Set the working directory as "To Source File Location"
library(plyr)
library(dplyr)
library(tidyverse)
library(broom)
library(mgcv)
library(lme4)
library(car)
library(MuMIn)
library(moments)
library(rcompanion)
library(wesanderson)
library(jtools)
library(grid)
library(patchwork)
library(ggpubr)

# Reading all samples and combing 99 samples ####
list.resa<-list.files("../Randomized_samples/samples/")

rf<- vector()
for (i in 1: length(list.resa)){
  j <- list.resa[i]
  print(j)
  rf_i<- readRDS(j)
  rf <- c(rf,rf_i)
}

median_values <- do.call("rbind", rf)

library(data.table)

all_rf<- t(median_values)
all_rf <- as.data.frame(all_rf)

names(rf_i)

rfcolna1 <- names(rf_i)

colnames(all_rf)<- paste(rep(rfcolna1, times=99))
rownames(all_rf) <- NULL
all_rf <- data.frame(all_rf)


all_rf21<- melt(setDT(all_rf), measure= patterns("Year","lat","lon","realm","taxa","source","ID","CTI","tas",
                                                 "body","thermal_breadth","species_count","species_STI","percent_sti",
                                                 "first_year","last_year","diff"), 
                value.name= c("Year","lat","lon","realm","taxa","source","ID","CTI","tas",
                              "body","thermal_breadth","species_count","species_STI","percent_sti",
                              "first_year","last_year","diff"))[,variable:=NULL][]

all_rf2<- all_rf21[!is.na(all_rf21$CTI),]
names(all_rf2)
all_rf2$Year<-as.numeric(all_rf2$Year)
all_rf2$lat<-as.numeric(all_rf2$lat)
all_rf2$lon<-as.numeric(all_rf2$lon)
all_rf2$CTI<-as.numeric(all_rf2$CTI)
all_rf2$tas<-as.numeric(all_rf2$tas)
all_rf2$body<-as.numeric(all_rf2$body)
all_rf2$thermal_breadth<-as.numeric(all_rf2$thermal_breadth)
all_rf2$species_count<-as.numeric(all_rf2$species_count)
all_rf2$species_STI<-as.numeric(all_rf2$species_STI)
all_rf2$percent_sti<- as.numeric(all_rf2$percent_sti)
all_rf2$first_year<- as.numeric(all_rf2$first_year)
all_rf2$last_year<-as.numeric(all_rf2$last_year)
all_rf2$diff <- as.numeric(all_rf2$diff)

# Taking the median value of each variable across 99 samples ####
median_all_cti<- ddply(all_rf2,.(lat,lon,Year,realm,source,taxa,ID),summarise,CTI=median(CTI,na.rm=TRUE),
                       tas = median(tas,na.rm=TRUE),body = median(body,na.rm=TRUE),
                       thermal_breadth = median(thermal_breadth,na.rm=TRUE), species_count = median(species_count,na.rm=TRUE),
                       species_STI = median(species_STI,na.rm=TRUE),
                       first_year = median(first_year,na.rm=TRUE),last_year = median(last_year,na.rm=TRUE),
                       diff = median(diff,na.rm=TRUE))

names(median_all_cti)
unique(median_all_cti$taxa)
median_all_cti$taxa[median_all_cti$taxa == "1"]<- "Plants"
median_all_cti$taxa[median_all_cti$taxa == "2"]<- "Terrestrial_insects"
median_all_cti$taxa[median_all_cti$taxa == "3"]<- "Birds"
median_all_cti$taxa[median_all_cti$taxa == "4"]<- "Mammals"
median_all_cti$taxa[median_all_cti$taxa == "5"]<- "Phytoplankton"
median_all_cti$taxa[median_all_cti$taxa == "6"]<- "Zooplankton"
median_all_cti$taxa[median_all_cti$taxa == "7"]<- "Aquatic_insects"
median_all_cti$taxa[median_all_cti$taxa == "8"]<- "Fish"

# Separating the baseline values ####
initial1<-median_all_cti %>% 
  group_by(lat,lon,source,realm,taxa,ID) %>% 
  slice(which.min(Year))
initial1 <- as.data.frame(initial1)

names(initial1)
colnames(initial1)[8:11]<- c("base_CTI","base_tas","base_Body","base_niche_breadth")


library(broom)
# Calculating the temperature change at each site ####
temp_trends<- median_all_cti %>% 
  group_by(lat, lon,source,realm,taxa,ID) %>%
  do(tidy(lm(tas ~ Year, data = .))) %>% 
  filter(term == "Year") 

temp_trends <- temp_trends[,c("estimate","taxa","source","realm","lat","lon","ID","p.value")]
colnames(temp_trends)[1]<- "warming"

# Calculating the thermophilisation at each site ####
CTI_trends1<- median_all_cti %>% 
  group_by(lat, lon,source,realm,taxa,ID) %>%
  do(tidy(lm(CTI ~ Year, data = .))) %>% 
  filter(term == "Year") 

CTI_trends1 <- CTI_trends1[,c("estimate","taxa","source","lat","lon","ID")]
colnames(CTI_trends1)[1]<- "Thermophilisation"
library(rcompanion)

d1 <-CTI_trends1[!is.na(CTI_trends1$Thermophilisation),]

d1<- as.data.frame(d1)
temp_trends <- as.data.frame(temp_trends)
d1<- left_join(d1,temp_trends)
d1<- unique(d1)
d1<- left_join(d1,initial1)


saveRDS(d1,"d1_02_09_23.RData")

