
## Code for assigning species to the list that persisted, were added or lost at each time point 
## comm_data is all the community data that is all the raw community data
### Imran Khaliq #####
# Set the working directory as "To Source File Location"
library(plyr)
library(dplyr)
library(tidyverse)
library(broom)
library(mgcv)
library(lme4)
library(car)
library(MuMIn)
library(moments)
library(rcompanion)
library(wesanderson)
library(jtools)
library(grid)
library(patchwork)
library(ggpubr)

comm_data <- readRDS("../comm_data.RData")
unique_time_series <- unique(comm_data$ID)

results_list <- pbapply::pblapply(unique_time_series, function(ID) {
  
  tmp <- comm_data %>% filter(ID == ID)
  Years <- sort(unique(tmp$Year))
  n <- length(Years)
  series <- seq_len(n)
  pairs <- data.frame(start = series[-n], 
                      end = series[-1])
  
  pairs$start <- Years[pairs$start]
  pairs$end <- Years[pairs$end]
  
  output <-
    lapply(split(pairs, seq_len(nrow(pairs))), function(d) {
      
      # d <- pairs[1, , drop = FALSE]
      start <- tmp[tmp$Year == d$start, ]
      end <- tmp[tmp$Year == d$end, ]
      
      species <- unique(c(start$species, end$species))
      
      persist <- start$species[start$species %in% end$species]
      lost    <- start$species[!(start$species %in% end$species)]
      new     <- end$species[!(end$species %in% start$species)]
      
      
      fate <- data.frame(species = c(persist, lost, new), 
                         fate = c(rep("persist", length(persist)), 
                                  rep("lost", length(lost)), 
                                  rep("new", length(new)))
      )
      
      out <- 
        data.frame(
          time_id = start$ID[1],
          species = species,
          start = start$Year[1], 
          end = end$Year[1]
        )
      
      
      out$fate <- fate$fate[match(out$species, fate$species)]
      
      out
      
    }) |> dplyr::bind_rows()
  
  
})


names(results_list) = unique_time_series

saveRDS(results_list,"results_list_fate.RData")



